@@ -4,7 +4,10 @@ from .DeepLearningNewsvendor import DeepLearningNewsvendor
 from .RandomForestNewsvendor import RandomForestNewsvendor
 from .DecisionTreeNewsvendor import DecisionTreeNewsvendor
 from .LightGradientBoostingNewsvendor import LightGradientBoostingNewsvendor
+from .HoltWintersNewsvendor import HoltWintersNewsvendor
+from .WeightedNewsvendor import RandomForestWeightedNewsvendor, KNeighborsWeightedNewsvendor, EqualWeightedNewsvendor
 
 __all__ = ["EmpiricalRiskMinimizationNewsvendor", "KernelOptimizationNewsvendor",
            "DeepLearningNewsvendor", "RandomForestNewsvendor", "DecisionTreeNewsvendor",
-           "LightGradientBoostingNewsvendor"]
\ No newline at end of file
+           "LightGradientBoostingNewsvendor", "HoltWintersNewsvendor", "RandomForestWeightedNewsvendor",
+           "KNeighborsWeightedNewsvendor", "EqualWeightedNewsvendor"]
\ No newline at end of file
